---
title: item-12 Check property_class for all `Item` properties
---

`property_class` is inferred for `Item` properties, if parsing is not successful.
Check on all `Item` properties, whether the class is correct.
